Merge "gralloc1: Rename property to disable ubwc for graphics"
diff --git a/libgralloc1/gr_adreno_info.cpp b/libgralloc1/gr_adreno_info.cpp
index 6addcbf..1d0ed48 100644
--- a/libgralloc1/gr_adreno_info.cpp
+++ b/libgralloc1/gr_adreno_info.cpp
@@ -77,10 +77,10 @@
     return false;
   }
 
   // Check if the overriding property debug.gralloc.gfx_ubwc_disable_
   // that disables UBWC allocations for the graphics stack is set
   char property[PROPERTY_VALUE_MAX];
-  property_get("debug.gralloc.gfx_ubwc_disable_", property, "0");
+  property_get("debug.gralloc.gfx_ubwc_disable", property, "0");
   if (!(strncmp(property, "1", PROPERTY_VALUE_MAX)) ||
       !(strncmp(property, "true", PROPERTY_VALUE_MAX))) {
     gfx_ubwc_disable_ = true;
@@ -77,10 +77,10 @@
   }
 
-  // Check if the overriding property debug.gralloc.gfx_ubwc_disable_
+  // Check if the overriding property debug.gralloc.gfx_ubwc_disable
   // that disables UBWC allocations for the graphics stack is set
   char property[PROPERTY_VALUE_MAX];